{ pkgs, ... }:
let
  pname = "dump1090-fa";
  version = "8.2";
in
pkgs.stdenv.mkDerivation {
  inherit pname version;

  src = pkgs.fetchFromGitHub {
    owner = "flightaware";
    repo = "dump1090";
    rev = "v${version}";
    hash = "sha256-SUvK9XTXIDimEMEnORnp/Af/F030TZTxLI43Jzz31Js=";
  };

  outputs = [ "out" "html" ];

  nativeBuildInputs = [
    pkgs.pkg-config
  ];
  propagatedBuildInputs = [
    pkgs.ncurses
    pkgs.librtlsdr
    pkgs.libbladeRF
    pkgs.limesuite
    pkgs.hackrf
  ];
  buildFlags = [
    "DUMP1090_VERSION=v${version}"
    "CPUFEATURES=yes"
    "showconfig"
    "dump1090"
    "faup1090"
    "view1090"
  ];
  installPhase = ''
    runHook preInstall
    mkdir -p $out/bin
    install -D dump1090 $out/bin
    install -D faup1090 $out/bin
    install -D view1090 $out/bin
    mkdir -p $html
    cp -a public_html/* $html
    runHook postInstall
  '';
  meta = with pkgs.lib; {
    homepage = "https://github.com/flightaware/dump1090";
    description = "A ADS-B, Mode S, and Mode 3A/3C demodulator and decoder.";
    longDescription = ''
      dump1090-fa is a ADS-B, Mode S, and Mode 3A/3C demodulator and decoder that will receive and decode aircraft transponder messages received via a directly connected software defined radio, or from data provided over a network connection.

      It is the successor to dump1090-mutability and is maintained by FlightAware.

      It can provide a display of locally received aircraft data in a terminal or via a browser map. Together with PiAware it can be used to contribute crowd-sourced flight tracking data to FlightAware.
    '';
    license = licenses.gpl2Plus;
  };
}
