{ pkgs, ... }:
let
  pname = "tcllauncher";
  version = "1.10";
in
pkgs.stdenv.mkDerivation {
  inherit pname version;

  src = pkgs.fetchFromGitHub {
    owner = "flightaware";
    repo = pname;
    rev = "v${version}";
    sha256 = "sha256-BVrsoczKeBBoM1Q3v6EJY81QwsX6xbUqFkcBb482WH4=";
  };
  nativeBuildInputs = [
    pkgs.autoconf
    pkgs.makeBinaryWrapper
  ];
  propagatedBuildInputs = [
    pkgs.tcl
    pkgs.tclx
    pkgs.tcllib
  ];
  dontPatch = true;
  preConfigure = ''
    autoconf
  '';
  configureFlags = [
    "--with-tcl=${pkgs.tcl}/lib"
  ];
  buildFlags = [
    ''pkglibdir=''${out}/lib''
  ];
  installFlags = [
    ''DESTDIR=''${out}''
    "bindir=/bin"
    "includedir=/include"
    "mandir=/share/man"
    "pkglibdir=/lib"
  ];
  # postFixup = ''
  #   wrapProgram $out/bin/tcllauncher \
  #     --set TCLLIBPATH "${pkgs.tcl}/lib ${pkgs.tclx}/lib"
  # '';
  # buildFlags = [
  #   "DUMP1090_VERSION=${version}"
  #   "CPUFEATURES=yes"
  # ];
  # installPhase = ''
  #   runHook preInstall
  #   mkdir -p $out
  #   make DESTDIR=$out install
  #   runHook postInstall
  # '';
  meta = with pkgs.lib; {
    homepage = "https://flightaware.github.io/tcllauncher/";
    description = "Launcher program for Tcl applications.";
    longDescription = ''
      tcllauncher is a way to have Tcl programs run out of /usr/local/bin under their own name, be installed in one place with their support files, and provides commands to facilitate server-oriented application execution.
    '';
    license = licenses.gpl2Plus;
  };
}
